##  Organization-Specific Technology Assessment
You can assign different assessments for the same IT component across different business units, lines of business, or legal entities. You can do that by moving the technology assessment field to the relation between the IT component and the organization fact sheet in the meta model. This allows you, for example, to assess an IT component as 'Adopt' for one organization and 'Trial' for another organization where that IT component has a different purpose.
In the radar report, you can select such single-select fields on relation as a parameter for either the sector or the ring. When you do, a dialog will prompt you to choose a specific organization, ensuring the generated report is built specifically for the selected organization.
**Note**
The radar report does not support aggregating data from multiple relations simultaneously.
